@@ -16,12 +16,14 @@ from vzg.jconv.interfaces import IConverter
 from vzg.jconv.gapi import NAMESPACES
 from vzg.jconv.gapi import JSON_SCHEMA
 from vzg.jconv.gapi import JATS_SPRINGER_PUBTYPE
-from vzg.jconv.gapi import JATS_SPRINGER_JOURNALTYPE
+from vzg.jconv.gapi import JATS_XPATHS
+from vzg.jconv.gapi import PUBTYPE_SOURCES
 from vzg.jconv.langcode import ISO_639
 from vzg.jconv.publisher import getPublisherId
+from vzg.jconv.journal import JatsJournal
 from vzg.jconv.errors import NoPublisherError
 from vzg.jconv.utils import node2text
-from vzg.jconv.utils import flatten_line
+from vzg.jconv.utils import get_pubtype_suffix
 from vzg.jconv.utils.date import JatsDate
 from lxml import etree
 import logging
@@ -31,55 +33,6 @@ import jsonschema
 __author__ = """Marc-J. Tegethoff <marc.tegethoff@gbv.de>"""
 __docformat__ = "plaintext"
 
-JATS_XPATHS = {}
-JATS_XPATHS["lang_code"] = "//article-meta/title-group/article-title/@xml:lang"
-JATS_XPATHS["journal-title"] = "//journal-meta/journal-title-group/journal-title/text()"
-JATS_XPATHS["pub-date"] = """//article-meta/pub-date[@date-type="{pubtype}"]"""
-JATS_XPATHS[
-    "pub-date-format"
-] = """//article-meta/pub-date[@publication-format="{pubtype}"]"""
-JATS_XPATHS["pub-date-year"] = JATS_XPATHS["pub-date"] + """/year/text()"""
-JATS_XPATHS[
-    "primary_id"
-] = """//article-meta/article-id[@pub-id-type="publisher-id"]/text()"""
-JATS_XPATHS[
-    "other_ids_doi"
-] = """//article-meta/article-id[@pub-id-type="doi"]/text()"""
-JATS_XPATHS["article-title"] = "//article-meta/title-group/article-title"
-JATS_XPATHS[
-    "journal-id"
-] = """//journal-meta/journal-id[@journal-id-type="{journaltype}"]/text()"""
-JATS_XPATHS["journal-issn"] = """//journal-meta/issn[@pub-type="{pubtype}"]/text()"""
-JATS_XPATHS[
-    "journal-issn-pformat"
-] = """//journal-meta/issn[@publication-format="{pubtype}"]/text()"""
-JATS_XPATHS["journal-volume"] = """//article-meta/volume/text()"""
-JATS_XPATHS["journal-issue"] = """//article-meta/issue/text()"""
-JATS_XPATHS["journal-start_page"] = """//article-meta/fpage/text()"""
-JATS_XPATHS["journal-end_page"] = """//article-meta/lpage/text()"""
-JATS_XPATHS["publisher-name"] = """//journal-meta/publisher/publisher-name/text()"""
-JATS_XPATHS["publisher-place"] = """//journal-meta/publisher/publisher-loc/text()"""
-JATS_XPATHS["article-persons"] = """//article-meta/contrib-group/contrib"""
-JATS_XPATHS[
-    "article-copyright"
-] = """//article-meta/permissions/copyright-statement/text()"""
-JATS_XPATHS[
-    "article-license-type"
-] = """//article-meta/permissions/license/@license-type"""
-JATS_XPATHS[
-    "article-custom-meta"
-] = """//article-meta/custom-meta-group/custom-meta/meta-name"""
-JATS_XPATHS[
-    "article-oa-license"
-] = """//article-meta/permissions/license[contains(@xlink:href, 'creativecommons.org')]"""
-JATS_XPATHS["affiliation"] = """//article-meta/contrib-group/aff[@id="{rid}"]"""
-JATS_XPATHS["abstracts-lang_code"] = "//article-meta/abstract/@xml:lang"
-JATS_XPATHS["abstracts"] = "//article-meta/abstract"
-JATS_XPATHS["abstracts-sec"] = "//article-meta/abstract/sec"
-JATS_XPATHS["abstracts-sec-node"] = ".//sec"
-JATS_XPATHS["subjects-lang_code"] = "//article-meta/kwd-group/@xml:lang"
-JATS_XPATHS["subjects"] = "//article-meta/kwd-group"
-
 
 @implementer(IArticle)
 class JatsArticle:
@@ -101,11 +54,20 @@ class JatsArticle:
     None
     """
 
-    def __init__(self, dom, pubtype, iso639=None, publisher=None):
+    def __init__(
+        self,
+        dom,
+        pubtype,
+        iso639=None,
+        publisher=None,
+        pubtype_source=PUBTYPE_SOURCES.basic,
+    ):
         self.dom = dom
         self.iso639 = ISO_639() if isinstance(iso639, type(None)) else iso639
         self.pubtype = pubtype
         self.publisher = publisher
+        self.pubtype_source = pubtype_source
+        self._journal = JatsJournal(article=self)
 
     @property
     def abstracts(self):
@@ -157,14 +119,18 @@ class JatsArticle:
     def copyright(self):
         """Article copyright"""
         logger = logging.getLogger(__name__)
-        nodes = self.xpath(JATS_XPATHS["article-copyright"])
 
-        copyr = ""
+        stms = ("article-copyright", "article-copyright-short")
+        copyr = "no copyright information available"
 
-        try:
-            copyr = nodes[0].strip()
-        except IndexError:
-            logger.debug("no copyright")
+        for stm in stms:
+            nodes = self.xpath(JATS_XPATHS[stm])
+
+            try:
+                copyr = nodes[0].strip()
+                break
+            except IndexError:
+                logger.debug("no copyright")
 
         return copyr
 
@@ -194,7 +160,7 @@ class JatsArticle:
     def lang_code(self):
         """Article lang_code"""
         logger = logging.getLogger(__name__)
-        attributes = self.xpath(JATS_XPATHS["lang_code"])
+        attributes = self.xpath(JATS_XPATHS["primary_lang_code"])
         lcode = []
 
         try:
@@ -204,122 +170,10 @@ class JatsArticle:
 
         return lcode
 
-    @property
-    def journal_date(self):
-        """Look for the earliest date"""
-        logger = logging.getLogger(__name__)
-
-        date_node = None
-
-        expression = JATS_XPATHS["pub-date"].format(pubtype="pub")
-        nodes = self.dom.xpath(expression, namespaces=NAMESPACES)
-        basictype = len(nodes) > 0
-
-        for pubtype in JATS_SPRINGER_PUBTYPE:
-            if basictype:
-                logger.debug("new pub")
-                expression = JATS_XPATHS["pub-date-format"].format(pubtype=pubtype.name)
-            else:
-                expression = JATS_XPATHS["pub-date"].format(pubtype=pubtype.value)
-
-            node = self.dom.xpath(expression, namespaces=NAMESPACES)
-
-            if len(node) > 0:
-                dnode = JatsDate(node[0])
-
-                if isinstance(date_node, JatsDate):
-                    if dnode.todate() < date_node.todate():
-                        date_node = dnode
-                else:
-                    date_node = dnode
-
-        return date_node
-
     @property
     def journal(self):
         """Article journal"""
-        logger = logging.getLogger(__name__)
-
-        pdict = {"title": "", "year": "", "journal_ids": []}
-
-        jids = {
-            "emerald": [JATS_XPATHS["journal-id"].format(journaltype="publisher")],
-            "springer": [JATS_XPATHS["journal-id"].format(journaltype="publisher-id")],
-            "doi": [JATS_XPATHS["journal-id"].format(journaltype="doi")],
-            self.pubtype.value: [
-                JATS_XPATHS["journal-issn"].format(pubtype=self.pubtype.value),
-                JATS_XPATHS["journal-issn-pformat"].format(pubtype=self.pubtype.name),
-            ],
-        }
-
-        expression = JATS_XPATHS["journal-title"]
-        node = self.xpath(expression)
-        try:
-            pdict["title"] = node[0].strip()
-        except IndexError:
-            logger.debug("no journal title")
-
-        date_node = self.journal_date
-
-        if isinstance(date_node.month, int):
-            pdict["month"] = f"{date_node.month:02}"
-            if isinstance(date_node.day, int):
-                pdict["day"] = f"{date_node.day:02}"
-
-        if isinstance(date_node.year, int):
-            pdict["year"] = f"{date_node.year}"
-
-        for jtype, expressions in jids.items():
-            for expression in expressions:
-                node = self.xpath(expression)
-
-                if len(node) == 0:
-                    msg = f"no {jtype} journal_id ({self.pubtype.value})"
-                    logger.debug(msg)
-                    continue
-
-                jid = {"type": jtype, "id": node[0]}
-
-                if jid["type"] in JATS_SPRINGER_JOURNALTYPE.__members__:
-                    jid["type"] = JATS_SPRINGER_JOURNALTYPE[jid["type"]].value
-
-                pdict["journal_ids"].append(jid)
-
-        publisher = {}
-
-        expression = JATS_XPATHS["publisher-name"]
-        node = self.xpath(expression)
-        try:
-            publisher["name"] = node[0].strip()
-        except IndexError:
-            logger.debug("no publisher name")
-
-        expression = JATS_XPATHS["publisher-place"]
-        node = self.xpath(expression)
-        try:
-            publisher["place"] = node[0].strip()
-        except IndexError:
-            logger.debug("no publisher place")
-
-        if len(publisher) > 0:
-            pdict["publisher"] = publisher
-
-        jdata = {
-            "journal-volume": "volume",
-            "journal-issue": "issue",
-            "journal-start_page": "start_page",
-            "journal-end_page": "end_page",
-        }
-
-        for xkey, attr in jdata.items():
-            expression = JATS_XPATHS[xkey]
-            node = self.xpath(expression)
-            try:
-                pdict[attr] = node[0]
-            except IndexError:
-                logger.debug(f"no journal {attr}")
-
-        return pdict
+        return self._journal.as_dict()
 
     @property
     def jdict(self):
@@ -337,9 +191,9 @@ class JatsArticle:
         }
 
         if isinstance(self.dateOfProduction, JatsDate) and isinstance(
-            self.journal_date, JatsDate
+            self._journal.date, JatsDate
         ):
-            if self.dateOfProduction.todate() != self.journal_date.todate():
+            if self.dateOfProduction.todate() != self._journal.date.todate():
                 jdict["dateOfProduction"] = str(self.dateOfProduction)
 
         if self.pubtype.value == JATS_SPRINGER_PUBTYPE.electronic.value:
@@ -419,11 +273,7 @@ class JatsArticle:
         try:
             doi_path = node[0].split("/")
             pdict["id"] = doi_path[-1]
-
-            if self.pubtype.value == JATS_SPRINGER_PUBTYPE.print.value:
-                pdict["id"] += "-p"
-            elif self.pubtype.value == JATS_SPRINGER_PUBTYPE.electronic.value:
-                pdict["id"] += "-e"
+            pdict["id"] += get_pubtype_suffix(self.pubtype.value)
 
             return pdict
         except (IndexError, ValueError):
@@ -434,11 +284,7 @@ class JatsArticle:
 
         try:
             pdict["id"] = node[0]
-
-            if self.pubtype.value == JATS_SPRINGER_PUBTYPE.print.value:
-                pdict["id"] += "-p"
-            elif self.pubtype.value == JATS_SPRINGER_PUBTYPE.electronic.value:
-                pdict["id"] += "-e"
+            pdict["id"] += get_pubtype_suffix(self.pubtype.value)
         except IndexError:
             logger.debug("no primary_id")
 
@@ -609,6 +455,7 @@ class JatsConverter:
         self.jatspath = jatspath
         self.articles = []
         self.publisher = publisher
+        self.pubtype_source = PUBTYPE_SOURCES.basic
 
         if not self.jatspath.is_file():
             raise OSError
@@ -633,14 +480,27 @@ class JatsConverter:
 
         pubtypes = []
 
+        # Springer
         expression = JATS_XPATHS["pub-date"].format(pubtype="pub")
         nodes = self.dom.xpath(expression, namespaces=NAMESPACES)
-        basictype = len(nodes) > 0
+        if len(nodes) > 0:
+            self.pubtype_source = PUBTYPE_SOURCES.springer
+
+        # deGruyter
+        if self.pubtype_source == PUBTYPE_SOURCES.basic:
+            expression = JATS_XPATHS["pub-date-pubtype"]
+            nodes = self.dom.xpath(expression, namespaces=NAMESPACES)
+            if len(nodes) > 0:
+                self.pubtype_source = PUBTYPE_SOURCES.degruyter
 
         for entry in JATS_SPRINGER_PUBTYPE:
-            if basictype:
+            if self.pubtype_source == PUBTYPE_SOURCES.springer:
                 logger.debug("new pub")
                 expression = JATS_XPATHS["pub-date-format"].format(pubtype=entry.name)
+            elif self.pubtype_source == PUBTYPE_SOURCES.degruyter:
+                expression = JATS_XPATHS["pub-date-pubtype-val"].format(
+                    pubtype=entry.value
+                )
             else:
                 expression = JATS_XPATHS["pub-date"].format(pubtype=entry.value)
 
@@ -657,8 +517,13 @@ class JatsConverter:
         """"""
         logger = logging.getLogger(__name__)
 
+        if self.dom.docinfo.root_name != "article":
+            return None
+
         for pubtype in self.pubtypes:
-            article = JatsArticle(self.dom, pubtype, self.iso639, self.publisher)
+            article = JatsArticle(
+                self.dom, pubtype, self.iso639, self.publisher, self.pubtype_source
+            )
 
             if self.validate:
                 try:
